Package 'savvyExamples'

Title: Examples of savvy
Description: No description.
Authors: Hiroaki Yutani [aut, cre] (ORCID: <https://orcid.org/0000-0002-3385-7233>)
Maintainer: Hiroaki Yutani <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0
Built: 2026-05-23 09:11:58 UTC
Source: https://github.com/yutannihilation/savvy

Help Index


Add suffix

Description

Add suffix

Usage

add_suffix(x, y)

Arguments

x

A character vector.

y

A suffix.

Value

A character vector with upper case version of the input.


Flip Input

Description

Flip Input

Usage

flip_logical(x)

Arguments

x

A logical vector.

Value

A logical vector with filled values (NA is converted to TRUE).


A Or B.

Description

A Or B.

Usage

FooEnum

Format

An object of class savvyExamples::FooEnum__bundle (inherits from savvy_savvyExamples__sealed) of length 2.


Or operation

Description

Or operation

Usage

or_logical(x, y)

Arguments

x

A logical vector.

y

A logical value.

Value

A logical vector with filled values (NA is converted to TRUE).


A person with a name

Description

A person with a name

Usage

Person

Format

An object of class savvyExamples::Person__bundle (inherits from savvy_savvyExamples__sealed) of length 5.


Reverse bits

Description

Reverse bits

Usage

reverse_bit_scalar(x)

Arguments

x

A raw vector.


Reverse bits

Description

Reverse bits

Usage

reverse_bits(x)

Arguments

x

A raw vector.


Multiply Input By Another Input

Description

Multiply Input By Another Input

Usage

times_any_int(x, y)

Arguments

x

An integer vector.

y

An integer to multiply.

Value

An integer vector with values multiplied by y.


Multiply Input By Another Input

Description

Multiply Input By Another Input

Usage

times_any_real(x, y)

Arguments

x

A real vector.

y

A real to multiply.

Value

A real vector with values multiplied by y.


Multiply Input By Two

Description

Multiply Input By Two

Usage

times_two_int(x)

Arguments

x

An integer vector.

Value

An integer vector with values multiplied by 2.


Multiply Input By Two

Description

Multiply Input By Two

Usage

times_two_real(x)

Arguments

x

A numeric vector.

Value

A numeric vector with values multiplied by 2.


Convert Input To Upper-Case

Description

Convert Input To Upper-Case

Usage

to_upper(x)

Arguments

x

A character vector.

Value

A character vector with upper case version of the input.