| Title: | Examples of savvy |
|---|---|
| Description: | No description. |
| Authors: | Hiroaki Yutani [aut, cre] (ORCID: <https://orcid.org/0000-0002-3385-7233>) |
| Maintainer: | Hiroaki Yutani <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0 |
| Built: | 2026-05-23 09:11:58 UTC |
| Source: | https://github.com/yutannihilation/savvy |
Add suffix
add_suffix(x, y)add_suffix(x, y)
x |
A character vector. |
y |
A suffix. |
A character vector with upper case version of the input.
Flip Input
flip_logical(x)flip_logical(x)
x |
A logical vector. |
A logical vector with filled values (NA is converted to TRUE).
A Or B.
FooEnumFooEnum
An object of class savvyExamples::FooEnum__bundle (inherits from savvy_savvyExamples__sealed) of length 2.
Or operation
or_logical(x, y)or_logical(x, y)
x |
A logical vector. |
y |
A logical value. |
A logical vector with filled values (NA is converted to TRUE).
A person with a name
PersonPerson
An object of class savvyExamples::Person__bundle (inherits from savvy_savvyExamples__sealed) of length 5.
Print the content of list
print_list(x)print_list(x)
x |
A list vector. |
NULL
Reverse bits
reverse_bit_scalar(x)reverse_bit_scalar(x)
x |
A raw vector. |
Reverse bits
reverse_bits(x)reverse_bits(x)
x |
A raw vector. |
Multiply Input By Another Input
times_any_int(x, y)times_any_int(x, y)
x |
An integer vector. |
y |
An integer to multiply. |
An integer vector with values multiplied by y.
Multiply Input By Another Input
times_any_real(x, y)times_any_real(x, y)
x |
A real vector. |
y |
A real to multiply. |
A real vector with values multiplied by y.
Multiply Input By Two
times_two_int(x)times_two_int(x)
x |
An integer vector. |
An integer vector with values multiplied by 2.
Multiply Input By Two
times_two_real(x)times_two_real(x)
x |
A numeric vector. |
A numeric vector with values multiplied by 2.
Convert Input To Upper-Case
to_upper(x)to_upper(x)
x |
A character vector. |
A character vector with upper case version of the input.